# -*- coding: utf-8 -*-
#
#  Copyright (C) 2005-2009 by Shyouzou Sugitani <shy@users.sourceforge.jp>
#
#  This program is free software; you can redistribute it and/or modify it
#  under the terms of the GNU General Public License (version 2) as
#  published by the Free Software Foundation.  It is distributed in the
#  hope that it will be useful, but WITHOUT ANY WARRANTY; without even the
#  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#  PURPOSE.  See the GNU General Public License for more details.
#

NUMBER = '4.0.1'
CODENAME = 'jump off into never-never land'

VERSION = '%s (%s)' % (NUMBER, CODENAME)
VERSION_INFO = (''.join((r'\h\s[0]\w8ninix-aya %s\n' % VERSION,
                         unicode(_('Are igai No Nanika with "Nin\'i" for X'),
                                 'utf-8'),
                         r'\n',
                         r'\_q'
                         r'Copyright (c) 2001, 2002 Tamito KAJIYAMA\n'
                         r'Copyright (c) 2002-2006 MATSUMURA Namihiko\n'
                         r'Copyright (c) 2002-2009 Shyouzou Sugitani\n'
                         r'Copyright (c) 2002, 2003 ABE Hideaki\n'
                         r'Copyright (c) 2003-2005 Shun-ichi TAHARA\e')))
